@@ -1,8 +1,8 @@
-__all__ = ["classifier", "regression", "recommender", "stat", "graph", "anomaly"]
+__all__ = ["anomaly", "classifier", "graph", "recommender", "regression", "stat", ]
 
-from jubatus.classifier.client import classifier as Classifier
-from jubatus.regression.client import regression as Regression
-from jubatus.recommender.client import recommender as Recommender
-from jubatus.stat.client import stat as Stat
-from jubatus.graph.client import graph as Graph
 from jubatus.anomaly.client import anomaly as Anomaly
+from jubatus.classifier.client import classifier as Classifier
+from jubatus.graph.client import graph as Graph
+from jubatus.recommender.client import recommender as Recommender
+from jubatus.regression.client import regression as Regression
+from jubatus.stat.client import stat as Stat
